=================
Contributor Guide
=================

Contributor License Agreement
-----------------------------

.. index::
   single: license; agreement

In order to contribute to the Tacker-Horizon project, you need to have
signed OpenStack's contributor's agreement. You can find the details
of how to contribute as the link below.

.. seealso::

   * http://docs.openstack.org/infra/manual/developers.html
   * http://wiki.openstack.org/CLA

LaunchPad Project
-----------------

Most of the tools used for OpenStack depend on a launchpad.net ID for
authentication.

.. seealso::

   * https://launchpad.net
   * https://launchpad.net/tacker

Project Info
------------

* Free software: under the `Apache license <http://www.apache.org/licenses/LICENSE-2.0>`_
* Tacker service: https://opendev.org/openstack/tacker
* Tacker-horizon library: https://opendev.org/openstack/tacker-horizon
* Bugs tracker: https://bugs.launchpad.net/tacker
* Blueprints: https://blueprints.launchpad.net/tacker
* Code review: https://review.opendev.org/#/q/status:open+project:openstack/tacker-horizon,n,z
